@@ -90,6 +90,7 @@ def test_collect_vms():
                 'summary.config.memorySizeMB': 1024,
                 'runtime.maxCpuUsage': 2400,
                 'summary.config.template': False,
+                'summary.config.vmPathName': '[datastore-1] vm-1/vm-1.vmx',
                 'runtime.bootTime': boot_time,
                 'snapshot': snapshot,
                 'guest.disk': [disk],
@@ -98,7 +99,7 @@ def test_collect_vms():
                 'guest.toolsVersionStatus2': 'guestToolsUnmanaged',
             }
         })
-        assert collector.vm_labels.result == {'vm-1': ['vm-1', 'n/a', 'n/a', 'n/a']}
+        assert collector.vm_labels.result == {'vm-1': ['vm-1', 'datastore-1', 'n/a', 'n/a', 'n/a']}
 
     # Test template True
 
@@ -129,6 +130,7 @@ def test_collect_vms():
                 'summary.config.numCpu': 1,
                 'summary.config.memorySizeMB': 1024,
                 'summary.config.template': True,
+                'summary.config.vmPathName': '[datastore-1] vm-1/vm-1.vmx',
                 'runtime.bootTime': boot_time,
                 'snapshot': snapshot,
                 'guest.disk': [disk],
@@ -140,7 +142,7 @@ def test_collect_vms():
         yield collector._vmware_get_vms(metrics)
         assert _check_properties(batch_fetch_properties.call_args[0][1])
         assert collector.vm_labels.result == {
-            'vm-1': ['vm-1', 'host-1', 'dc', 'cluster-1'],
+            'vm-1': ['vm-1', 'datastore-1', 'host-1', 'dc', 'cluster-1'],
         }
 
     assert metrics['vmware_vm_template'].samples[0][2] == 1.0
@@ -175,6 +177,7 @@ def test_collect_vms():
                 'summary.config.memorySizeMB': 1024,
                 'runtime.maxCpuUsage': 2400,
                 'summary.config.template': False,
+                'summary.config.vmPathName': '[datastore-1] vm-1/vm-1.vmx',
                 'runtime.bootTime': boot_time,
                 'snapshot': snapshot,
                 'guest.disk': [disk],
@@ -189,6 +192,7 @@ def test_collect_vms():
                 'summary.config.memorySizeMB': 1024,
                 'runtime.maxCpuUsage': 2400,
                 'summary.config.template': False,
+                'summary.config.vmPathName': '[datastore-1] vm-2/vm-2.vmx',
                 'runtime.bootTime': boot_time,
                 'snapshot': snapshot,
                 'guest.disk': [disk],
@@ -204,6 +208,7 @@ def test_collect_vms():
                 'summary.config.memorySizeMB': 1024,
                 'runtime.maxCpuUsage': 2400,
                 'summary.config.template': False,
+                'summary.config.vmPathName': '[datastore-1] vm-3/vm-3.vmx',
                 'runtime.bootTime': boot_time,
                 'snapshot': snapshot,
                 'guest.disk': [disk],
@@ -215,14 +220,15 @@ def test_collect_vms():
         yield collector._vmware_get_vms(metrics)
         assert _check_properties(batch_fetch_properties.call_args[0][1])
         assert collector.vm_labels.result == {
-            'vm-1': ['vm-1', 'host-1', 'dc', 'cluster-1'],
-            'vm-2': ['vm-2', 'n/a', 'n/a', 'n/a'],
-            'vm-3': ['vm-3', 'host-1', 'dc', 'cluster-1'],
+            'vm-1': ['vm-1', 'datastore-1', 'host-1', 'dc', 'cluster-1'],
+            'vm-2': ['vm-2', 'datastore-1', 'n/a', 'n/a', 'n/a'],
+            'vm-3': ['vm-3', 'datastore-1', 'host-1', 'dc', 'cluster-1'],
         }
 
     # Assert that vm-3 skipped #69/#70
     assert metrics['vmware_vm_power_state'].samples[1][1] == {
         'vm_name': 'vm-3',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -231,6 +237,7 @@ def test_collect_vms():
     # General VM metrics
     assert metrics['vmware_vm_power_state'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -239,6 +246,7 @@ def test_collect_vms():
 
     assert metrics['vmware_vm_boot_timestamp_seconds'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -248,6 +256,7 @@ def test_collect_vms():
     # Disk info (vmguest)
     assert metrics['vmware_vm_guest_disk_capacity'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -258,6 +267,7 @@ def test_collect_vms():
     # VM tools info (vmguest)
     assert metrics['vmware_vm_guest_tools_running_status'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -267,6 +277,7 @@ def test_collect_vms():
 
     assert metrics['vmware_vm_guest_tools_version'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -276,6 +287,7 @@ def test_collect_vms():
 
     assert metrics['vmware_vm_guest_tools_version_status'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -286,6 +298,7 @@ def test_collect_vms():
     # Snapshots
     assert metrics['vmware_vm_snapshots'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -294,6 +307,7 @@ def test_collect_vms():
 
     assert metrics['vmware_vm_snapshot_timestamp_seconds'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -303,6 +317,7 @@ def test_collect_vms():
 
     assert metrics['vmware_vm_snapshot_timestamp_seconds'].samples[1][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -313,6 +328,7 @@ def test_collect_vms():
     # Max Memory
     assert metrics['vmware_vm_memory_max'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -322,6 +338,7 @@ def test_collect_vms():
     # Max Cpu
     assert metrics['vmware_vm_max_cpu_usage'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -371,6 +388,7 @@ def test_metrics_without_hostaccess():
                 'summary.config.memorySizeMB': 1024,
                 'runtime.maxCpuUsage': 2400,
                 'summary.config.template': False,
+                'summary.config.vmPathName': '[datastore-1] vm-x/vm-x.vmx',
                 'runtime.bootTime': boot_time,
                 'guest.disk': [disk],
                 'guest.toolsStatus': 'toolsOk',
@@ -378,13 +396,14 @@ def test_metrics_without_hostaccess():
                 'guest.toolsVersionStatus2': 'guestToolsUnmanaged',
             }
         })
-        assert collector.vm_labels.result == {'vm-1': ['vm-x', 'n/a', 'n/a', 'n/a']}
+        assert collector.vm_labels.result == {'vm-1': ['vm-x', 'datastore-1', 'n/a', 'n/a', 'n/a']}
         yield collector._vmware_get_vms(metrics)
 
         # 113 AssertionError {'partition': '/boot'} vs {'host_name': '/boot'}
         assert metrics['vmware_vm_guest_disk_capacity'].samples[0][1] == {
             'vm_name': 'vm-x',
             'partition': '/boot',
+            'ds_name': 'datastore-1',
             'host_name': 'n/a',
             'cluster_name': 'n/a',
             'dc_name': 'n/a',
@@ -394,6 +413,7 @@ def test_metrics_without_hostaccess():
         # but found ['vm-1']
         assert metrics['vmware_vm_power_state'].samples[0][1] == {
             'vm_name': 'vm-x',
+            'ds_name': 'datastore-1',
             'host_name': 'n/a',
             'cluster_name': 'n/a',
             'dc_name': 'n/a',
@@ -553,7 +573,7 @@ def test_collect_vm_perf():
     })
 
     collector.__dict__['vm_labels'] = _succeed({
-        'vm:1': ['vm-1', 'host-1', 'dc', 'cluster-1'],
+        'vm:1': ['vm-1', 'datastore-1', 'host-1', 'dc', 'cluster-1'],
     })
 
     collector.__dict__['vm_inventory'] = _succeed({
@@ -574,6 +594,7 @@ def test_collect_vm_perf():
     # General VM metrics
     assert metrics['vmware_vm_net_transmitted_average'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -582,6 +603,7 @@ def test_collect_vm_perf():
 
     assert metrics['vmware_vm_cpu_demand_average'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
@@ -590,6 +612,7 @@ def test_collect_vm_perf():
 
     assert metrics['vmware_vm_disk_maxTotalLatency_latest'].samples[0][1] == {
         'vm_name': 'vm-1',
+        'ds_name': 'datastore-1',
         'host_name': 'host-1',
         'cluster_name': 'cluster-1',
         'dc_name': 'dc',
