@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- python -*-
 # -*- coding: utf-8 -*-
+# autopep8'd
 """
 Handles collection of metrics for vmware.
 """
@@ -91,10 +92,10 @@ class VmwareCollector():
 
         # label names and ammount will be needed later to insert labels from custom attributes
         self._labelNames = {
-            'vms': ['vm_name', 'host_name', 'dc_name', 'cluster_name'],
-            'vm_perf': ['vm_name', 'host_name', 'dc_name', 'cluster_name'],
-            'vmguests': ['vm_name', 'host_name', 'dc_name', 'cluster_name'],
-            'snapshots': ['vm_name', 'host_name', 'dc_name', 'cluster_name'],
+            'vms': ['vm_name', 'ds_name', 'host_name', 'dc_name', 'cluster_name'],
+            'vm_perf': ['vm_name', 'ds_name', 'host_name', 'dc_name', 'cluster_name'],
+            'vmguests': ['vm_name', 'ds_name', 'host_name', 'dc_name', 'cluster_name'],
+            'snapshots': ['vm_name', 'ds_name', 'host_name', 'dc_name', 'cluster_name'],
             'datastores': ['ds_name', 'dc_name', 'ds_cluster'],
             'hosts': ['host_name', 'dc_name', 'cluster_name'],
             'host_perf': ['host_name', 'dc_name', 'cluster_name'],
@@ -734,6 +735,7 @@ class VmwareCollector():
             'name',
             'runtime.host',
             'parent',
+            'summary.config.vmPathName',
         ]
 
         if self.collect_only['vms'] is True:
@@ -795,7 +797,6 @@ class VmwareCollector():
 
     @defer.inlineCallbacks
     def customAttributesLabelNames(self, metric_type):
-
         """
             vm perf, vms, vmguestes and snapshots metrics share the same custom attributes
             as they re related to virtual machine objects
@@ -1089,6 +1090,15 @@ class VmwareCollector():
 
             labels[moid] = [row['name']]
 
+            if 'summary.config.vmPathName' in row:
+                p = row['summary.config.vmPathName']
+                if p[0] == '[':
+                    p = p[1:p.find("]")]
+            else:
+                p = 'n/a'
+
+            labels[moid] = labels[moid] + [p]
+
             if host_moid in host_labels:
                 labels[moid] = labels[moid] + host_labels[host_moid]
 
@@ -1695,7 +1705,10 @@ class VmwareCollector():
             sensors = [s for s in sensors if ':' in s]
 
             for s in sensors:
-                sensor = dict(item.split("=") for item in s.split(":")[1:])
+                sensor = dict(item.split("=") for item in re.split(r':(?=\w+=)', s)[1:])
+
+                if not all(key in sensor for key in ['sensorStatus', 'name', 'type', 'unit', 'value']):
+                    continue
 
                 sensor_status = {
                     'red': 0,
